@@ -9,7 +9,7 @@
  *		dnsdomainname	
  *		nisdomainname {name|-F file}
  *
- * Version:	hostname 2.00 (1996-04-14)
+ * Version:	hostname 2.01 (1997-01-16)
  *
  * Author:	Peter Tobias <tobias@et-inf.fho-emden.de>
  *
@@ -23,6 +23,7 @@
  *960414 {2.00}	Peter Tobias :		minor changes for the standalone
  *					version, fixed a few spelling
  *					bugs
+ *970116 {2.01} Peter Tobias :          minor fixes
  *
  *		This program is free software; you can redistribute it
  *		and/or  modify it under  the terms of  the GNU General
@@ -52,7 +53,7 @@
 #include "net-locale.h"
 
 char *Release = RELEASE,
-     *Version = "hostname 2.00";
+     *Version = "hostname 2.01";
      
 static char *program_name;
 static int  opt_v;
@@ -232,7 +233,7 @@ static void usage(void)
 	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage12, 
 		"    -y, --yp, --nis       NIS/YP domain name\n"));
 	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage13, 
-		"    -F, --file            read host name or NIS domain name from given File\n\n"));
+		"    -F, --file            read host name or NIS domain name from given file\n\n"));
 	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage14, 
 		"   This comand can get or set the host name or the NIS domain name. You can\n"));
 	fprintf(stderr,NLS_CATGETS(catfd, hostnameSet, hostname_usage15, 
@@ -376,3 +377,4 @@ int main(int argc, char **argv)
 	NLS_CATCLOSE(catfd)
 	exit(0);
 }
+
